@@ -189,6 +189,9 @@ class ModelConverter:
 
         self._tensor_cache[tensor_id] = converted_tensor
 
+        # for layers that don't implements the name override
+        self._tensor_name_to_original_tensor_name[converted_tensor.name] = tensor.name
+
         return converted_tensor
 
     @staticmethod
